@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_imagebuilder.type_defs import (
@@ -101,6 +102,7 @@ class ImagebuilderClient:
     [Imagebuilder.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/imagebuilder.html#Imagebuilder.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
